bayespy.inference.vmp.nodes.expfamily.ExponentialFamily.add_plate_axis
======================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.expfamily

.. automethod:: ExponentialFamily.add_plate_axis